@@ -16,14 +16,11 @@ class DiarioshuffleCommand(rc.Command):
     syntax = ""
 
     async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
-        DiarioT = self.alchemy.get(Diario)
-        entry: List[Diario] = await ru.asyncify(
-            data.session
-                .query(DiarioT)
-                .order_by(func.random())
-                .limit(1)
-                .one_or_none
-        )
-        if entry is None:
-            raise rc.CommandError("Nessuna riga del diario trovata.")
-        await data.reply(f"ℹ️ {entry}")
+        async with data.session_acm() as session:
+            DiarioT = self.alchemy.get(Diario)
+            entry: List[Diario] = await ru.asyncify(
+                session.query(DiarioT).order_by(func.random()).limit(1).one_or_none
+            )
+            if entry is None:
+                raise rc.CommandError("Nessuna riga del diario trovata.")
+            await data.reply(f"ℹ️ {entry}")
