@@ -7,7 +7,6 @@ import royalnet.commands as rc
 import royalnet.utils as ru
 
 from .abstract.linker import LinkerCommand
-from ..types import Updatable
 from ..tables import Osu
 from ..stars.api_auth_login_osu import ApiAuthLoginOsuStar
 
@@ -58,9 +57,7 @@ class OsuCommand(LinkerCommand):
 
     async def update(self, session, obj: Osu, change: Callable[[str, Any], Awaitable[None]]):
         await obj.refresh_if_expired(client_id=self.client_id,
-                                     client_secret=self.client_secret,
-                                     base_url=self.base_url,
-                                     path=ApiAuthLoginOsuStar.path)
+                                     client_secret=self.client_secret)
         async with aiohttp.ClientSession(headers={"Authorization": f"Bearer {obj.access_token}"}) as session:
             async with session.get("https://osu.ppy.sh/api/v2/me/osu") as response:
                 m = await response.json()
@@ -118,7 +115,7 @@ class OsuCommand(LinkerCommand):
         if attribute == "standard_pp":
             await self.notify(f"⬜️ [b]{obj.user}[/b] non è più classificato su [i]osu![/i].")
         elif attribute == "taiko_pp":
-            await self.notify(f" ⬜️[b]{obj.user}[/b] non è più classificato su [i]osu!taiko[/i].")
+            await self.notify(f"⬜️ [b]{obj.user}[/b] non è più classificato su [i]osu!taiko[/i].")
         elif attribute == "catch_pp":
             await self.notify(f"⬜️ [b]{obj.user}[/b] non è più classificato su [i]osu!catch[/i].")
         elif attribute == "mania_pp":
