@@ -1,5 +1,6 @@
 from typing import *
 
+import functools
 import pkg_resources
 import royalnet.commands as rc
 
@@ -12,14 +13,12 @@ class RoyalpackCommand(rc.Command):
     syntax: str = ""
 
     @property
-    def royalpack_version(self):
+    @functools.lru_cache(1)
+    def royalpack_version(self) -> str:
         return pkg_resources.get_distribution("royalpack").version
 
     async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
-        if __debug__:
-            message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/]Unreleased[/url]\n"
-        else:
-            message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/releases/tag/{self.royalpack_version}]{self.royalpack_version}[/url]\n"
+        message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/releases/tag/{self.royalpack_version}]{self.royalpack_version}[/url]\n"
         if "69" in self.royalpack_version:
             message += "(Nice.)"
         await data.reply(message)
