@@ -22,8 +22,8 @@ class SteampoweredCommand(LinkerCommand):
 
     syntax: str = "{url_profilo}"
 
-    def __init__(self, interface: rc.CommandInterface):
-        super().__init__(interface)
+    def __init__(self, serf, config):
+        super().__init__(serf, config)
         self._api = steam.webapi.WebAPI(self.token())
 
     def token(self):
@@ -57,10 +57,12 @@ class SteampoweredCommand(LinkerCommand):
         )
 
         await FiorygiTransaction.spawn_fiorygi(
-            data=data,
             user=user,
             qty=1,
-            reason="aver collegato a Royalnet il proprio account di League of Legends"
+            reason="aver collegato a Royalnet il proprio account di Steam",
+
+            data=data,
+            session=session,
         )
 
         session.add(steam_account)
