@@ -18,6 +18,7 @@ from .mmevents import MMEvent
 from .mmresponse import MMResponse
 from .cvstats import Cvstats
 from .treasure import Treasure
+from .osu import Osu
 
 # Enter the tables of your Pack here!
 available_tables = [
@@ -40,6 +41,7 @@ available_tables = [
     MMResponse,
     Cvstats,
     Treasure,
+    Osu,
 ]
 
 # Don't change this, it should automatically generate __all__
