@@ -4,6 +4,7 @@ import datetime
 from sqlalchemy import *
 from sqlalchemy.orm import *
 from sqlalchemy.ext.declarative import declared_attr
+import royalnet.utils as ru
 
 from .fiorygi import Fiorygi
 
@@ -46,24 +47,30 @@ class FiorygiTransaction:
         return f"<{self.__class__.__name__}: {self.change:+} to {self.user.username} for {self.reason}>"
 
     @classmethod
-    async def spawn_fiorygi(cls, data: "CommandData", user, qty: int, reason: str):
-        if user.fiorygi is None:
-            data.session.add(data._interface.alchemy.get(Fiorygi)(
-                user_id=user.uid,
-                fiorygi=0
-            ))
-            await data.session_commit()
+    async def spawn_fiorygi(cls, user, qty: int, reason: str, *, data: "CommandData", session):
+        FiorygiT = data.alchemy.get(cls)
+        FiorygiTransactionT = data.alchemy.get(FiorygiTransaction)
 
-        transaction = data._interface.alchemy.get(FiorygiTransaction)(
-            user_id=user.uid,
-            change=qty,
-            reason=reason,
-            timestamp=datetime.datetime.now()
+        if user.fiorygi is None:
+            session.add(
+                FiorygiT(
+                    user_id=user.uid,
+                    fiorygi=0
+                )
+            )
+            await ru.asyncify(session.commit)
+
+        session.add(
+            FiorygiTransactionT(
+                user_id=user.uid,
+                change=qty,
+                reason=reason,
+                timestamp=datetime.datetime.now()
+            )
         )
-        data.session.add(transaction)
 
         user.fiorygi.fiorygi += qty
-        await data.session_commit()
+        await ru.asyncify(session.commit)
 
         if len(user.telegram) > 0:
             user_str = user.telegram[0].mention()
@@ -77,6 +84,7 @@ class FiorygiTransaction:
         else:
             msg = f"💸 [b]{user_str}[/b] ha perso [b]{-qty}[/b] fioryg{'i' if qty != -1 else ''} per [i]{reason}[/i]."
 
-        await data._interface.call_herald_event("telegram", "telegram_message",
-                                                chat_id=data._interface.config["Telegram"]["main_group_id"],
-                                                text=msg)
+        await data.command.serf.call_herald_event(
+            "telegram", "telegram_message",
+            chat_id=data.command.config["Telegram"]["main_group_id"],
+            text=msg)
